<template>
  <div class="trend">
    <div class="title">
      <span>数据趋势</span>
      <img src="../../../assets/img/zonlan (9).png" alt="" />
    </div>
    <div class="content">
      <div id="trend_box"></div>
    </div>
  </div>
</template>

<script>
import { constructionData } from "../../../utils/api.js";
export default {
  //import引入的组件需要注入到对象中才能使用
  components: {},
  data() {
    //这里存放数据
    return {
      param: {
        TYPE: 6,
      },
    };
  },
  //方法集合
  methods: {
    async construction() {
      let { data: dt } = await constructionData(this.param);
      if (dt.errno !== 200) {
        return this.$message.error(dt.errmsg);
      }

      let val = {
        nyvarList: [],
        sjlvarList: [],
        sjzzlvarList: [],
      };
      dt.nyvarList.forEach((element) => {
        val.nyvarList.push(element.ny);
      });
      dt.sjlvarList.forEach((element) => {
        val.sjlvarList.push(element.sjl);
      });
      dt.sjzzlvarList.forEach((element) => {
        val.sjzzlvarList.push(element.sjzzl);
      });
      this.drawLine(val);
    },
    drawLine(val) {
      // console.log(val);
      // 基于准备好的dom，初始化echarts实例
      let Chart = this.$echarts.init(document.getElementById("trend_box"));
      let option = {
        baseOption: {
          tooltip: {
            trigger: "axis",
            axisPointer: {
              type: "cross",
              crossStyle: {
                color: "#999",
              },
            },
          },
          grid: {
            left: "5%",
            right: "5%",
          },
          legend: {
            right: "10%",
            data: ["数据总量", "增长率（%）"],
            textStyle: {
              //图例文字的样式
              color: "#fff",
              fontSize: 20,
            },
          },
          xAxis: [
            {
              type: "category",
              data: val.nyvarList,
              // data: ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
              axisPointer: {
                type: "shadow",
              },
              axisLabel: {
                textStyle: {
                  color: "#fff",
                  fontSize: 25,
                },
              },
            },
          ],
          yAxis: [
            {
              type: "value",
              // name: "水量",
              // min: 200000000,
              // max: 450000000,
              // interval: 50000000,
              axisLabel: {
                formatter: "{value}",
                textStyle: {
                  color: "#fff",
                  fontSize: 25,
                },
              },
            },
            {
              type: "value",
              // name: "温度",
              min: 0,
              max: 25,
              interval: 5,
              axisLabel: {
                formatter: "{value}",
                textStyle: {
                  color: "#fff",
                  fontSize: 25,
                },
              },
            },
          ],
          series: [
            {
              name: "数据总量",
              type: "bar",
              itemStyle: {
                normal: {
                  color: {
                    type: "linear",
                    x: 0,
                    y: 0,
                    x2: 0,
                    y2: 1,
                    colorStops: [
                      {
                        offset: 0,
                        color: "rgba(166,255,246,.4)", // 0% 处的颜色
                      },
                      {
                        offset: 1,
                        color: "rgba(0,160,233,.6)", // 100% 处的颜色
                      },
                    ],
                    global: false, // 缺省为 false
                  },
                },
              },
              data: val.sjlvarList,
              // data: [
              //   2.0, 4.9, 7.0, 23.2, 25.6, 76.7, 135.6, 162.2, 32.6, 20.0, 6.4,
              //   3.3,
              // ],
            },

            {
              name: "增长率（%）",
              type: "line",
              yAxisIndex: 1,
              itemStyle: {
                normal: {
                  color: "#F8DC3F",
                },
              },
              data: val.sjzzlvarList,
              // data: [
              //   2.0, 2.2, 3.3, 4.5, 6.3, 10.2, 20.3, 23.4, 23.0, 16.5, 12.0,
              //   6.2,
              // ],
            },
          ],
        }, //媒体查询
        // media: [
        //   {
        //     query: {
        //       minWidth: 100,
        //     },
        //     option: {
        //       grid: {
        //         left: "10%",
        //         right: "10%",
        //       },
        //       legend: {
        //         textStyle: {
        //           //图例文字的样式

        //           fontSize: 10,
        //         },
        //       },
        //       xAxis: [
        //         {
        //           axisLabel: {
        //             textStyle: {
        //               fontSize: 10,
        //             },
        //           },
        //         },
        //       ],
        //       yAxis: [
        //         {
        //           axisLabel: {
        //             textStyle: {
        //               fontSize: 10,
        //             },
        //           },
        //         },
        //         {
        //           axisLabel: {
        //             textStyle: {
        //               fontSize: 10,
        //             },
        //           },
        //         },
        //       ],
        //       series: [],
        //     },
        //   },
        // ],
      };
      // 绘制图表
      Chart.setOption(option);
    },
  },
  mounted() {
    this.construction();
    // this.drawLine();
  },
  created() {},
};
</script>
<style lang="less" scoped>
//@import url(); 引入公共css类
.trend {
  overflow: hidden;
  width: 100%;
  height: 49%;
  margin-top: 0.5%;
  box-sizing: border-box;
  background: rgba(8, 32, 58, 0.7);
  .title {
    width: 100%;
    position: relative;
    text-align: center;
    img {
      width: 2100px;
    }
    span {
      font-size: 78px;
      font-weight: 400;
      color: #ffe86b;
      background: linear-gradient(0deg, #bce7ff 0%, #69efff 98.6572265625%);
      -webkit-background-clip: text;
      -webkit-text-fill-color: transparent;
      position: absolute;
      left: 50%;
      top: 0;
      transform: translateX(-50%);
    }
  }
  .content {
    width: 100%;
    height: 95%;
    box-sizing: border-box;
    display: flex;
    flex-wrap: wrap;
    justify-content: space-evenly;
    align-items: center;
    #trend_box {
      width: 100%;
      height: 100%;
    }
  }
}
@media only screen and (max-width: 2560px) {
  .trend {
    height: auto;
    overflow: visible;
    // margin-top: 400px;
    background: transparent;
    .title {
      margin-top: 200px;
      img {
        width: 100%;
      }
    }
    .content {
      height: auto;
      #trend_box {
        width: 100%;
        height: 4000px;
      }
    }
  }
}
</style>
